@@ -217,6 +217,19 @@ class Manager(object):
             self.comprobante.cfe_number
         )
 
+    def get_document_received_report(self):
+
+        conn_obj = conn.Connector()
+
+        return conn_obj.get_document_received_report(
+            self.connection_data,
+            self.comprobante.vat,
+            self.comprobante.rut_received,
+            self.comprobante.cfe_code,
+            self.comprobante.cfe_serial,
+            self.comprobante.cfe_number
+        )
+
     def send_document(self):
         """
         Envia los datos del comprobante a webservice para su validacion
