@@ -75,7 +75,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        Manager(self.emisor, comprobante, self.connection_data).send_document()
+        Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         connection_data = objects.ConnectionData()
         connection_data.url = 'https://test.ucfe.com.uy/Query116/WebServicesFE.svc?wsdl'
@@ -86,7 +86,7 @@ class TestUruware(unittest.TestCase):
         connection_data.terminal_code = 'FC-582'
         connection_data.timeout = '30000'
 
-        report = Manager(self.emisor, comprobante, connection_data).get_document_report()
+        report = Manager(connection_data, comprobante, self.emisor).get_document_report()
         assert '%PDF' in report.decode('latin-1')
 
     # 6.2.2.1 Ejemplo para e-Factura
@@ -127,7 +127,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -171,7 +171,7 @@ class TestUruware(unittest.TestCase):
         comprobante.payment_method = "1"
         comprobante.own_collection = True
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -212,7 +212,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -246,7 +246,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -282,7 +282,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -317,7 +317,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -355,7 +355,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -393,7 +393,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -432,7 +432,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -465,7 +465,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -504,7 +504,7 @@ class TestUruware(unittest.TestCase):
         comprobante.currency = 'UYU'
         comprobante.fiscal_data = mandatario
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -551,7 +551,7 @@ class TestUruware(unittest.TestCase):
         comprobante.refund_info = refund
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -590,7 +590,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -629,7 +629,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -658,7 +658,7 @@ class TestUruware(unittest.TestCase):
         comprobante.transport_type = 1
         comprobante.picking_lines = [line1]
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -698,7 +698,7 @@ class TestUruware(unittest.TestCase):
         comprobante.transport_type = 1
         comprobante.refund_info = refund
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -734,7 +734,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -805,7 +805,7 @@ class TestUruware(unittest.TestCase):
         comprobante.retentions = [retention1, retention2]
         comprobante.refund_info = refund
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -859,7 +859,7 @@ class TestUruware(unittest.TestCase):
         comprobante.currency = 'UYU'
         comprobante.retentions = [retention1, retention2]
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -905,7 +905,7 @@ class TestUruware(unittest.TestCase):
         comprobante.retentions = [retention1]
         comprobante.references = refund
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -952,7 +952,7 @@ class TestUruware(unittest.TestCase):
         comprobante.retentions = [retention1]
         comprobante.refund_info = refund
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
@@ -998,7 +998,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1036,7 +1036,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1078,7 +1078,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1121,7 +1121,7 @@ class TestUruware(unittest.TestCase):
         comprobante.currency = 'UYU'
         comprobante.fiscal_data = mandatario
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1171,7 +1171,7 @@ class TestUruware(unittest.TestCase):
         comprobante.refund_info = refund
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1213,7 +1213,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1245,7 +1245,7 @@ class TestUruware(unittest.TestCase):
         comprobante.picking_lines = [line1]
         comprobante.transport_type = 1
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1288,7 +1288,7 @@ class TestUruware(unittest.TestCase):
         comprobante.transport_type = 1
         comprobante.refund_info = refund
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1327,7 +1327,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1385,7 +1385,7 @@ class TestUruware(unittest.TestCase):
         comprobante.currency = 'UYU'
         comprobante.retentions = [retention1, retention2]
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1435,7 +1435,7 @@ class TestUruware(unittest.TestCase):
         comprobante.retentions = [retention1]
         comprobante.refund_info = refund
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
@@ -1476,14 +1476,14 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
         comprobante.cfe_serial = msg.get('responseBody').Resp.Serie
         comprobante.cfe_number = msg.get('responseBody').Resp.NumeroCfe
 
-        msg_state = Manager(self.emisor, comprobante, self.connection_data).get_cfe_state()
+        msg_state = Manager(self.connection_data, comprobante, self.emisor).get_cfe_state()
 
         assert not msg_state.get('responseMsg')
 
@@ -1525,7 +1525,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg_first = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg_first = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         # partner factura
         partner_vat = objects.Vat(215404940014, 2)
@@ -1561,7 +1561,7 @@ class TestUruware(unittest.TestCase):
         comprobante.invoice_lines = [line1, line2]
         comprobante.currency = 'UYU'
 
-        msg_second = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg_second = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert msg_first.get('responseBody').Resp.XmlCfeFirmado == msg_second.get('responseBody').Resp.XmlCfeFirmado
 
@@ -1603,6 +1603,6 @@ class TestUruware(unittest.TestCase):
         comprobante.currency = 'UYU'
         comprobante.decimal_places = 3
 
-        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+        msg = Manager(self.connection_data, comprobante, self.emisor).send_document()
 
         assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
